@@ -1,10 +1,11 @@
 import json
 
-import vogeler.log as logger
-from vogeler.exceptions import VogelerServerException
+import vogeler.logger as logger
+import vogeler.conf as conf
+import vogeler.exceptions as exceptions
+
 from vogeler.messaging import amqp
 
-log = logger.setup_logger(logLevel='DEBUG', logFile=None, name='vogeler-server')
 
 class VogelerServer(object):
     """
@@ -28,11 +29,40 @@ class VogelerServer(object):
 
     """
     def __init__(self, callback_function=None, **kwargs):
+        self._configured = False
+
+        if kwargs.has_key("config"):
+            self._configure(kwargs["config"])
+            self._configured = True
+
+        if kwargs.has_key("loglevel"):
+            log_level = kwargs["loglevel"]
+        elif self._configured is True and self._config.has_option('global', 'log_level'):
+            log_level = self._config.get('global', 'log_level')
+        else:
+            log_level = 'WARN'
+
+        self.log = logger.LogWrapper(name='vogeler-server', level=log_level).logger()
+
+        if kwargs.has_key("dsn"):
+            _dsn = kwargs["dsn"]
+        elif self._configured is True and self._config.has_option('amqp', 'dsn'):
+            _dsn = self._config.get('amqp', 'dsn')
+        else:
+            error = "No dsn provided. Cannot continue"
+            self.log.fatal(error)
+            raise exceptions.VogelerMessagingException(error)
+
         try:
-            self.ch, self.queue = amqp.setup_server(kwargs['host'], kwargs['username'], kwargs['password'])
+            self.ch, self.queue = amqp.setup_server(_dsn)
             self.callback_function = callback_function
-        except:
-            raise VogelerServerException("Unable to connect to messaging system on %s as %s" % (kwargs['host'], kwargs['username']))
+        except Exception, e:
+            raise e
+
+    def _configure(self, config_file=None):
+        if config_file is not None:
+            self._config = conf.configure(cfg=config_file)
+            self._configured = True
 
     def callback(self, msg):
         """
@@ -44,8 +74,9 @@ class VogelerServer(object):
         """
         try:
             message = json.loads(msg.body)
-        except:
-            log.error("Message not in JSON format")
+        except Exception, e:
+            self.log.error("Message not in JSON format: %s" % message)
+            raise exceptions.VogelerMessagingJSONException(e)
 
         if(self.callback_function):
             self.callback_function(message)
@@ -57,13 +88,15 @@ class VogelerServer(object):
         :raises: :class:`vogeler.exceptions.VogelerClientException`
         """
         try:
-            log.info("Vogeler(Server) is starting up")
+            self.log.debug("Vogeler(Server) is starting up")
             self.ch.basic_consume(self.queue, callback=self.callback, no_ack=True)
-        except:
-            log.fatal("Error Consuming queue")
-            raise VogelerServerException("Error consuming queue")
+            self.log.info("Vogler(Server) has started")
+        except Exception, e:
+            self.log.fatal("Error Consuming queue")
+            raise exceptions.VogelerMessagingException(e)
 
         while self.ch.callbacks:
+            self.log.info("Waiting for more messages")
             self.ch.wait()
 
     def message(self, message, durable=True):
@@ -79,15 +112,15 @@ class VogelerServer(object):
             instance of :class:`amqplib.client_0_8.basic_message.Message` wrapped in JSON
 
         """
-        log.info("Vogeler(Server) is sending a message")
+        self.log.info("Vogeler(Server) is sending a message")
         try:
             msg = amqp.amqp.Message(json.dumps(message))
             if durable == True:
                 msg.properties['delivery_mode'] = 2
             self.ch.basic_publish(msg, exchange=amqp.broadcast_exchange)
-        except:
-            log.fatal("Error publishing message to the queue")
-            raise VogelerServerException("Unable to publish message to the queue")
+        except Exception, e:
+            self.log.fatal("Error publishing message to the queue")
+            raise exceptions.VogelerMessagingException(e)
 
     def close(self):
         """Close the channel with the broker"""
